const apiConfig = {
  figuresUsersIndexApi: '/figures/api/user-index/',
  edxCourseInfoApi: '/api/courses/v1/courses/',
  edxUserInfoApi: '/api/user/v1/accounts/',
  courseEnrollmentsApi: '/figures/api/course-enrollments/',
  generalSiteMetrics: '/figures/api/general-site-metrics/',
  coursesGeneral: '/figures/api/courses-general/',
  coursesDetailed: '/figures/api/courses-detail/',
  learnersGeneral: '/figures/api/users-general/',
  learnersDetailed: '/figures/api/users-detail/',
  reportingCsvReportsApi: '/reporting/api/csv-reports/',
  coursesIndex: '/figures/api/courses-index/',
  learnerMetrics: '/figures/api/learner-metrics/',
}

export default apiConfig;
